@@ -270,9 +270,6 @@ class ConvNet(pl.LightningModule):
             **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
         """
         super(ConvNet, self).__init__()
-
-        if 'optimizer_type' not in config.keys():
-            config.update({'optimizer_type' : 'adam'})
         
         self.model_type = model_type
         self.n_classes = n_classes
@@ -437,4 +434,50 @@ class ConvNet(pl.LightningModule):
             optimizer = torch.optim.SGD(self.parameters(),
                                         lr=self.hparams.lr)
 
-        return optimizer
\ No newline at end of file
+        return optimizer
+
+"""
+class GenerativeNet(pl.LightningModule):
+    def __init__(
+        self,
+        dims : Union[int, Tuple[int]],
+        sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
+        **config : Any
+    )->None:
+        super(GenerativeNet, self).__init__()
+
+        self.dims = dims
+        self.config = config
+        self.sample_weight = sample_weight
+        self.save_hyperparameters(*config)
+
+
+    def on_after_batch_transfer(self, batch, dataloader_idx=0):
+        # modify this part if you want to perform model reweigthing.
+        self.sample_weight = torch.ones_like(batch[1]).type_as(batch[1])
+        return batch
+        
+    def reset_weights(self, module):
+        if isinstance(module, nn.Linear):
+            module.reset_parameters()
+            
+    def _init_weights(self, module):
+        if isinstance(module, nn.Linear):
+            nn.init.kaiming_normal_(module.weight)
+        elif isinstance(module, nn.BatchNorm1d):
+            nn.init.constant_(module.weight, 1)
+            nn.init.constant_(module.bias, 0)
+
+    def configure_optimizers(self):
+
+        #optimizer_type_check(applicable_optimizer_type_list, self.config.optimizer_type)
+        if self.hparams.optimizer_type == "adam":
+            optimizer = torch.optim.Adam(self.parameters(),
+                                     lr=self.hparams.lr
+                                     )
+        elif self.hparams.optimizer_type == "sgd":
+            optimizer = torch.optim.SGD(self.parameters(),
+                                        lr=self.hparams.lr)
+        
+        return optimizer
+"""
\ No newline at end of file
